/**
 * \file mcql/core/quantificationmethod.cpp
 * \date 24/10/2024
 * \author Olivier Langella
 * \brief store parameters related to peak detection and quantification
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#include "quantificationmethod.h"

mcql::QuantificationMethod::QuantificationMethod(const QString &id) : m_id(id)
{
}

mcql::QuantificationMethod::~QuantificationMethod()
{
}

void
mcql::QuantificationMethod::addXicFilter(
  const pappso::FilterInterfaceSPtr &filter)
{
  m_xicFilterSuite.push_back(filter);
}

pappso::PrecisionPtr
mcql::QuantificationMethod::getXicExtractionMeanPrecisionPtr() const
{

  if(mp_xicExtractionLowerPrecisionPtr->unit() == pappso::PrecisionUnit::ppm)
    {
      return pappso::PrecisionFactory::getPpmInstance(
        (mp_xicExtractionLowerPrecisionPtr->getNominal() +
         mp_xicExtractionUppersPrecisionPtr->getNominal()) /
        2);
    }
  return pappso::PrecisionFactory::getDaltonInstance(
    (mp_xicExtractionLowerPrecisionPtr->getNominal() +
     mp_xicExtractionUppersPrecisionPtr->getNominal()) /
    2);
}

pappso::XicExtractMethod
mcql::QuantificationMethod::getXicExtractMethod() const
{
  return m_xicExtractMethod;
}

void
mcql::QuantificationMethod::setTraceDetectionInterfaceCstSPtr(
  const pappso::TraceDetectionInterfaceCstSPtr &detection)
{
  mcsp_traceDetectionInterfaceCstSPtr = detection;
}

void
mcql::QuantificationMethod::setXicExtractionLowerPrecisionPtr(
  pappso::PrecisionPtr precision)
{
  mp_xicExtractionLowerPrecisionPtr = precision;
}

void
mcql::QuantificationMethod::setXicExtractionUpperPrecisionPtr(
  pappso::PrecisionPtr precision)
{
  mp_xicExtractionUppersPrecisionPtr = precision;
}

void
mcql::QuantificationMethod::setXicExtractMethod(pappso::XicExtractMethod method)
{
  m_xicExtractMethod = method;
}

const pappso::FilterSuite &
mcql::QuantificationMethod::getXicFilterSuite() const
{
  return m_xicFilterSuite;
}

const pappso::MzRange
mcql::QuantificationMethod::getXicExtractionMzRange(double mz) const
{

  return pappso::MzRange(
    mz, mp_xicExtractionLowerPrecisionPtr, mp_xicExtractionUppersPrecisionPtr);
}

const pappso::TraceDetectionInterfaceCstSPtr &
mcql::QuantificationMethod::getTraceDetectionInterfaceCstSPtr() const
{
  return mcsp_traceDetectionInterfaceCstSPtr;
}
