/**
 * \file mcql/core/quantificationmethod.h
 * \date 24/10/2024
 * \author Olivier Langella
 * \brief store parameters related to peak detection and quantification
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once

#include <memory>
#include <QString>
#include <pappsomspp/types.h>
#include <pappsomspp/mzrange.h>
#include <pappsomspp/processing/filters/filtersuite.h>
#include <pappsomspp/processing/detection/tracedetectioninterface.h>

namespace mcql
{

class QuantificationMethod;

typedef std::shared_ptr<QuantificationMethod> QuantificationMethodSp;

/**
 * @todo write docs
 */
class QuantificationMethod
{
  public:
  /**
   * Default constructor
   */
  QuantificationMethod(const QString &id);

  /**
   * Destructor
   */
  virtual ~QuantificationMethod();


  void setXicExtractMethod(pappso::XicExtractMethod method);

  pappso::XicExtractMethod getXicExtractMethod() const;

  void setXicExtractionLowerPrecisionPtr(pappso::PrecisionPtr precision);

  void setXicExtractionUpperPrecisionPtr(pappso::PrecisionPtr precision);

  pappso::PrecisionPtr getXicExtractionMeanPrecisionPtr() const;

  void addXicFilter(const pappso::FilterInterfaceSPtr &filter);

  void setTraceDetectionInterfaceCstSPtr(
    const pappso::TraceDetectionInterfaceCstSPtr &detection);


  const pappso::TraceDetectionInterfaceCstSPtr &
  getTraceDetectionInterfaceCstSPtr() const;

  const pappso::FilterSuite &getXicFilterSuite() const;


  const pappso::MzRange getXicExtractionMzRange(double mz) const;


  private:
  const QString m_id;
  pappso::XicExtractMethod m_xicExtractMethod = pappso::XicExtractMethod::max;

  pappso::PrecisionPtr mp_xicExtractionLowerPrecisionPtr  = nullptr;
  pappso::PrecisionPtr mp_xicExtractionUppersPrecisionPtr = nullptr;


  /// the xic filters
  pappso::FilterSuite m_xicFilterSuite;


  /// the peak detection method for this quantification
  pappso::TraceDetectionInterfaceCstSPtr mcsp_traceDetectionInterfaceCstSPtr;
};
} // namespace mcql
