
/**
 * \file mcql/output/quantificationresultcboroutput.h
 * \date 24/11/2024
 * \author Olivier Langella
 * \brief quantification result cbor writer for MassChroqLight
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once

#include "quantificationresultwriterinterface.h"
#include <QStringList>
#include <QCborStreamWriter>


namespace mcql
{

class QuantificationResultCborOutput
  : public QuantificationResultWriterInterface
{
  public:
  /**
   * Default constructor
   */
  QuantificationResultCborOutput(QIODevice *device);

  /**
   * Destructor
   */
  ~QuantificationResultCborOutput();


  virtual void writePeptideProteinList(
    const std::vector<mcql::PeptideSp> &peptide_list) override;


  virtual void startPeptideMeasurements() override;
  virtual void write(
    const mcql::PeptideMeasurements &peptide_measurements,
    const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p) override;
  virtual void write(
    const mcql::MbrPeptideMeasurements &peptide_measurements,
    const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p) override;
  virtual void endPeptideMeasurements() override;

  private:
  void writeMsRun(const MsRun &msrun);
  void writeMeasurement(
    const mcql::PeptideMeasurements::Measurement &measurement,
    const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p);
  void writeTrace(const pappso::Trace &trace);
  void writeTracePeak(
    const pappso::TracePeak &peak,
    const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p);

  private:
  QCborStreamWriter *mpa_writer = nullptr;
  bool m_isTraceOutput          = false;
};
} // namespace mcql
