
/**
 * \file mcql/output/quantificationresultwriterinterface.h
 * \date 27/09/2024
 * \author Olivier Langella
 * \brief quantification result writer for MassChroqLight
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once
#include <memory>
#include "../core/msrun.h"
#include "../core/peptide.h"
#include "../core/mbrpeptidemeasurements.h"
#include "../core/peptidemeasurements.h"
#include <pappsomspp/msrun/alignment/msrunretentiontime.h>

namespace mcql
{


class QuantificationResultWriterInterface;

typedef std::shared_ptr<QuantificationResultWriterInterface>
  QuantificationResultWriterInterfaceSp;
/**
 * @todo write docs
 */
class QuantificationResultWriterInterface
{
  public:
  /**
   * Default constructor
   */
  QuantificationResultWriterInterface();

  /**
   * Destructor
   */
  virtual ~QuantificationResultWriterInterface();


  void setMsRunSp(mcql::MsRunSp msrun);
  void setQuantificationId(const QString &quantify_id);
  void setGroupId(const QString &withingroup);

  virtual void startPeptideMeasurements() = 0;
  virtual void
  write(const mcql::PeptideMeasurements &peptide_measurements,
        const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p) = 0;
  virtual void
  write(const mcql::MbrPeptideMeasurements &peptide_measurements,
        const pappso::MsRunRetentionTime<QString> *msrun_retention_time_p) = 0;
  virtual void endPeptideMeasurements()                                    = 0;

  virtual void
  writePeptideProteinList(const std::vector<mcql::PeptideSp> &peptide_list) = 0;


  static QString enumToString(PeakQualityCategory peak_category);

  protected:
  mcql::MsRunSp msp_currentMsRun;
  QString m_currentQuantifyId;
  QString m_currentGroupId;
};
} // namespace mcql
